/****************************************************************************
This DO file creates descriptive statistics (tables and graphs)
For WB GDFD project: Syrian Refugee Adolescents in Jordan.
Last updated: 2021.06.22
V25
IP
*****************************************************************************/

************************
*Attitudes underlying factors
************************

****GENDER ATTITUDES
use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear

*keep adults aged 15-59
keep if age>=15 & age<=59

foreach num of numlist 1 2 3 5 6 7 8 9 10 11 {
replace opinion`num'=4 if opinion`num'==5	

tabu opinion`num', gen(opinion_`num'_) 
replace opinion_`num'_1=. if opinion`num'==.
replace opinion_`num'_2=. if opinion`num'==.
replace opinion_`num'_3=. if opinion`num'==.
replace opinion_`num'_4=. if opinion`num'==.
}

gen combo2=1 if nationalitya==400 & adolescent==1
	replace combo2=2 if nationalitya==405 & adolescent==1
	replace combo2=3 if nationalitya==400 & adolescent==0
	replace combo2=4 if nationalitya==405 & adolescent==0	

*N check
	
tabu combo2 sex if opinion1!=.	
	
collapse opinion_* [aw=expan_indiv], by(combo2 sex) 

reshape long opinion_@_1 opinion_@_2 opinion_@_3 opinion_@_4, i(combo2 sex) j(opinion)

reshape long opinion__, i(combo2 sex opinion) j(answers 1-4)

label values answers agree

replace opinion__=opinion__*100

label define statements ///
1 "Women allowed to work" ///
2 "Husband help w/children" ///
3 "Husband help w/chores" ///
5 "Girls school for work" ///
6 "Women who work bad mothers" ///
7 "For autonomy, women must work" ///
8 "Women's work interferes w/marriage" ///
9 "Women should be leaders" ///
10 "Gender equity -- schooling" ///
11 "Gender equity -- treatment" , modify


label def agree 1 "Strongly agree" ///
2 "Agree" 3 "Neutral" 4 "Disagree or strongly disagree" , modify

label values answers agree
label values opinion statements


label define combo2 1 "Jor. Adol." 2 "Syr. Adol" 3 "Jor. Adults" 4 "Syr Adults", modify
label values combo2 combo2


*****four attitudes distributions by sex and nationality*****
keep if opinion==1 | opinion==2 | opinion==9 | opinion==10
#delimit ;
gr hbar opinion__,
        over(answers) over(combo2) over(opinion, relabel(1 `""Women allowed" "to work""' 2 `""Husband help" "w/children""' 3 `""Women should" "be leaders""' 4 `""Gender equity" "in schooling""')) by(sex, note("") row(1) compact) asyvars stack 
		blabel(bar, position(center) format(%2.0f) size(2.5))
        bargap(0)
		bar(1, color(gs14))
		bar(2, color(gs10)) 
		bar(3, color(gs7))
		bar(4, color(gs3))
		ylabel(0 (20) 100,labs(3) nogrid) ytitle("Percentage", size(4)) ///
		subtitle(, size(2.8) span) ysize(10) xsize(16)
		legend(  rows(2) size(3.5)) 
		title("" ) ;
#delimit cr		

graph save "Graphs and Tables/attitudes_towards_women.gph", replace
graph export "Graphs and Tables/attitudes_towards_women.png", width(800) replace




****Mobility
use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear

*keep only women 15-59
keep if age>=15 & age<=59
keep if sex==2

label define places 4 "At least one place" ///
	1 "Local market" ///
	2 "Doctor" ///
	3 "House of family/friends" ///
	
	
*creating binary variables for the mobility questions on going alone to certain places (can go alone with any level of permission/cannot go alone). Don't know responses coded as no (make up less than 0.5 percent of responses in any question)
foreach num of numlist 1/4 {

gen q8306b`num'=.
replace q8306b`num'=1 if q8306_`num'==1 | q8306_`num'==2 | q8306_`num'==3
replace q8306b`num'=0 if q8306_`num'==4 | q8306_`num'==98		
}

label variable q8306b1 "Mobility: local market (binary)"
label variable q8306b2 "Mobility: doctor (binary)"
label variable q8306b3 "Mobility: child's doctor (binary)"
label variable q8306b4 "Mobility: visits (binary)"

*can go to at least one place alone yes/no
gen q8306b5=.
replace q8306b5=1 if q8306b1==1 | q8306b2==1 | q8306b3==1 | q8306b4==1
replace q8306b5=0 if q8306b1==0 & q8306b2==0 & q8306b3==0 & q8306b4==0	
	
*Stat
tabu q8306b5 [aw=expan_indiv]	

	
gen combo2=1 if nationalitya==400 & adolescent==1
	replace combo2=2 if nationalitya==405 & adolescent==1
	replace combo2=3 if nationalitya==400 & adolescent==0
	replace combo2=4 if nationalitya==405 & adolescent==0	

*Check N
tabu combo2 if q8306b5!=.
	
collapse q8306b5 q8306b1 q8306b2 q8306b3 q8306b4 [aw=expan_indiv], by(combo2)

reshape long q8306b, i(combo) j(places 1-4)

replace q8306b=q8306b*100

label values places places

label define combo2 1 "Jordanian Adolescents" 2 "Syrian Adolescents" 3 "Jordanian Adults" 4 "Syrian Adults"
label values combo2 combo2


****by nationality****
#delimit ;
graph hbar q8306b, 
	 over(combo2) over(places) asyvars
	blabel(bar, format(%9.0f) size(3))
	bar(1, color(gs1))
	bar(2, color(gs6))
	bar(3, color(gs10))
	bar(4, color(gs13))
	ylabel(0 (10) 100, nogrid) ytitle("Percentage Can Go Alone", size(4)) ///
	legend(size(4) symxsize(6.5));
#delimit cr

graph save "Graphs and Tables/mobility.gph", replace
graph export "Graphs and Tables/mobility.png", width(800) replace


****Domestic violence
use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear

*keep only women 15-59
keep if age>=15 & age<=59
keep if sex==2


label define situations 7 "In at least one of the above" ///
	1 "If she burns the food" ///
	2 "If she neglects the children" ///
	3 "If she argues with him" ///
	4 "If she talks to other men" ///
	5 "If she wastes his money" ///
	6 "If she refuses to have sex" 
	
gen combo2=1 if nationalitya==400 & adolescent==1
	replace combo2=2 if nationalitya==405 & adolescent==1
	replace combo2=3 if nationalitya==400 & adolescent==0
	replace combo2=4 if nationalitya==405 & adolescent==0	

*Stat
tabu beatjustever [aw=expan_indiv]	

*N check
tabu combo if beatjustever!=.

rename beatjustever beatjust7
	
collapse beatjust7 beatjust1 beatjust2 beatjust3 beatjust4 beatjust5 beatjust6 [aw=expan_indiv], by(combo2)

reshape long beatjust, i(combo2) j( situations 1-7)

replace beatjust=(beatjust*100)

label values situations situations



label define combo2 1 "Jordanian Adolescents" 2 "Syrian Adolescents" 3 "Jordanian Adults" 4 "Syrian Adults"
label values combo2 combo2


#delimit ;
graph hbar beatjust, 
	over(combo2) over(situations) asyvars
	blabel(bar, format(%9.0f) size(3))
	bar(1, color(gs10))
	bar(2, color(gs1))
	bar(3, color(gs13))
	bar(4, color(gs6))
	ylabel(0 (5) 20, labs(small) nogrid) ytitle("Percentage Believe Domestic Violence Justified", size(3)) ///
	legend(size(3) symxsize(6.5));
#delimit cr

graph save "Graphs and Tables/violence_towards_women_age_nat.gph", replace
graph export "Graphs and Tables/violence_towards_women_age_nat.png", width(800) replace

	


****Decision-making involvement
use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear

*keep only women 15-59
keep if age>=15 & age<=59
keep if sex==2
	
gen combo2=1 if nationalitya==400 & adolescent==1
	replace combo2=2 if nationalitya==405 & adolescent==1
	replace combo2=3 if nationalitya==400 & adolescent==0
	replace combo2=4 if nationalitya==405 & adolescent==0	

*N check
tabu combo if fnlsayall1!=.
	
collapse fnlsayall1-fnlsayall6 [aw=expan_indiv], by(combo2)

reshape long fnlsayall, i(combo2) j( situations 1-6)

replace fnlsayall=(fnlsayall*100)

label define situations ///
	1 "Major household items" ///
	2 "Daily needs" ///
	3 "Visits to family/friends" ///
	4 "Daily food" ///
	5 "Doctor" ///
	6 "Clothes" 

label values situations situations

label define combo2 1 "Jordanian Adolescents" 2 "Syrian Adolescents" 3 "Jordanian Adults" 4 "Syrian Adults"
label values combo2 combo2


#delimit ;
graph hbar fnlsayall, 
	over(combo2) over(situations) asyvars
	blabel(bar, format(%9.0f) size(3))
	bar(1, color(gs10))
	bar(2, color(gs1))
	bar(3, color(gs13))
	bar(4, color(gs6))
	ylabel(0 (20) 100, labs(small) nogrid) ytitle("Percentage Involved in Decision", size(3)) ///
	legend(size(3) symxsize(6.5));
#delimit cr

graph save "Graphs and Tables/decisions_age_nat.gph", replace
graph export "Graphs and Tables/decisions_age_nat.png", width(800) replace

	

************************
*Outcomes
************************

use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear

set scheme s1mono

gen combo2=1 if nationalitya==400 & adolescent==1
	replace combo2=2 if nationalitya==405 & adolescent==1
	replace combo2=3 if nationalitya==400 & adolescent==0
	replace combo2=4 if nationalitya==405 & adolescent==0	
	
label define combo2 1 "Jordanian Adolescents" 2 "Syrian Adolescents" 3 "Jordanian Adults" 4 "Syrian Adults"
label values combo2 combo2	

gen combo3=1 if nationalitya==400 & sex==1
replace combo3=2 if nationalitya==405 & sex==1
replace combo3=3 if nationalitya==400 & sex==2
replace combo3=4 if nationalitya==405 & sex==2

la def Lcombo3 1 "Jordanian Males" 2 "Syrian Males" 3 "Jordanian Females" 4 "Syrian Females", modify
la val combo3 Lcombo3

*DOMESTIC WORK*

*domestic work hours by sex and nationality by type of work, stacked bar graph
graph bar (mean) c_q4002_04 c_q4002_06 c_q4002_10 c_q4002_11 c_q4002_01 [aw=expan_indiv], over(combo3, label(labsize(small)) relabel(1 `""Jordanian" "Males""' 2`""Syrian" "Males""' 3 `""Jordanian" "Females""' 4 `""Syrian" "Females""')) over(adolescent) legend(row(2) label(1 "Cooking") label(2 "Cleaning") label(3 "Shopping") label(4 "Care") label(5 "Other")) ytitle("Hours per week")  ysc(r(0 22)) stack blabel(total, position(outside) format(%3.1f)) 	bar(1, color(gs14)) ///
	bar(2, color(gs12)) ///
	bar(3, color(gs9)) ///
	bar(4, color(gs6)) ///
	bar(5, color(gs1)) 
	
foreach num of numlist 1/4 6/9 11/14 16/19 21/24 26/29 31/34 36/39 {
	di `num'
gr_edit .plotregion1.barlabels[`num'].Delete
}


graph save "Graphs and Tables/domestic_work_stackbar.gph", replace
graph export "Graphs and Tables/domestic_work_stackbar.png", width(800) replace

set scheme s1mono

*SCHOOL ENROLLMENT*

*Keep ages 10-19
keep if age<=19 & age>=10 & student!=.

*Triply interacted model for sex, age in Dec., group
logit student i.age##i.combo3 [pw=expan_indiv]

*Predicted probabilites
margins, over(age i.combo3) predict(pr) post

*Graphing predicted probabilies
mplotoffset, plotd(combo3) byopts(row(3) title("") yrescale xrescale) plotregion(margin(l=5 r=5 b=0 t=0)) ///
xtitle("Age") ytitle("Probability enrolled") ///
plot1opts(lcolor(gs7) lpatt(dash) mcolor(gs7))  ///
plot2opts(lcolor(gs1) lpatt("l") mcolor(gs1))  ///
ci1opts(lcolor(gs7) lpatt(dash) msize(4))  ///
ci2opts(lcolor(gs1) lpatt("l") msize(4))  ///
ylabel(0(.2)1.1) ytick(0(.2)1.1) xlabel() xtick() ///
title(" ") offset(0.05) ysize(12) xsize(20)

graph save "Graphs and Tables/enrollmentlogit.gph", replace
graph export "Graphs and Tables/enrollmentlogit.png", width(800) replace
