/****************************************************************************
This DO file performs factor analysis of JLMPS questions on gender role attitudes, attitudes toward domestic violence, mobility, decision making. It exports FA results to Excel. 
For WB GDFD project: Syrian Refugee Adolescents in Jordan.
Last updated: 2020.11.24
V22 CK
*****************************************************************************/

use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear

*All factor analyses in this file use the polychoric package*

sort indid
set seed 2342322

************
*MOBILITY*
************

*Uses three categories where 0=cannot go alone, 1=can go alone with permission and 2=can go aone with or without informing someone
polychoric q8306t1 q8306t2 q8306t4 [pw=expan_indiv]
display r(N)
global N = r(N)
matrix M = r(R)

*Means and SDs
mean q8306t1 q8306t2 q8306t4 [pw=expan_indiv]
matrix mean = r(table)[1,1...]
tabstat q8306t1 q8306t2 q8306t4 [aw=expan_indiv], statistics(sd) save
matrix sd = r(StatTotal)
factormat M, n($N) means(mean) sds(sd)

alpha q8306t1 q8306t2 q8306t4

predict factor1_mobil
label var factor1_mobil "Mobility Factor"

*Save scoring coeff. 
matlist r(scoef)
matrix MOB_SC = r(scoef)'


*estout results
*correlation matrix
matlist e(C)
matrix MOB_CORR = e(C)
matrix rownames MOB_CORR = market doctor visits
matrix colnames MOB_CORR = market doctor visits
estout matrix(MOB_CORR) using "Graphs and Tables/FAresulttables.xls", replace

*uniqueness
matlist e(Psi)
matrix MOB_UNIQ = e(Psi)
matrix colnames MOB_UNIQ = market doctor visits
estout matrix(MOB_UNIQ) using "Graphs and Tables/FAresulttables.xls", append

*Factor loadings 
matlist e(L)
matrix MOB_LOAD = e(L)'
matrix colnames MOB_LOAD = market doctor visits
estout matrix(MOB_LOAD) using "Graphs and Tables/FAresulttables.xls", append

*Scoring coefficients
matrix colnames MOB_SC = market doctor visits
estout matrix(MOB_SC) using "Graphs and Tables/FAresulttables.xls", append

*eigenvalues
matlist e(Ev)
matrix MOB_EV = e(Ev)
estout matrix(MOB_EV) using "Graphs and Tables/FAresulttables.xls", append



******************
*DECISION MAKING* 
******************
*Uses binary variables where 0=not involved in the decision and 1=involved in the decision

*women with or without children, married and unmarried
polychoric fnlsayall1 fnlsayall2 fnlsayall3 fnlsayall4 fnlsayall5 fnlsayall6 if fnlsayall1!=. & fnlsayall2!=. & fnlsayall3!=. & fnlsayall4!=. & fnlsayall5!=. & fnlsayall6!=. [pw=expan_indiv]
display r(N)
global N = r(N)
matrix P = r(R)

*Means and sds
mean fnlsayall1 fnlsayall2 fnlsayall3 fnlsayall4 fnlsayall5 fnlsayall6 if fnlsayall1!=. & fnlsayall2!=. & fnlsayall3!=. & fnlsayall4!=. & fnlsayall5!=. & fnlsayall6!=. [pw=expan_indiv]
matrix mean = r(table)[1,1...]
tabstat fnlsayall1 fnlsayall2 fnlsayall3 fnlsayall4 fnlsayall5 fnlsayall6 if fnlsayall1!=. & fnlsayall2!=. & fnlsayall3!=. & fnlsayall4!=. & fnlsayall5!=. & fnlsayall6!=. [aw=expan_indiv], statistics(sd) save
matrix sd = r(StatTotal)
factormat P, n($N) means(mean) sds(sd)

alpha fnlsayall1 fnlsayall2 fnlsayall3 fnlsayall4 fnlsayall5 fnlsayall6

predict factor1_decision1
label var factor1_decision1 "Decision Making Involvement Factor"


*Save scoring coeff. 
matlist r(scoef)
matrix DEC2_SC = r(scoef)'


*estout results
*correlation matrix
matlist e(C)
matrix DEC2_CORR = e(C)
matrix rownames DEC2_CORR = major_purch daily_purch visits food doctor clothes
matrix colnames DEC2_CORR = major_purch daily_purch visits food doctor clothes
estout matrix(DEC2_CORR) using "Graphs and Tables/FAresulttables.xls", append

*uniqueness
matlist e(Psi)
matrix DEC2_UNIQ = e(Psi)
matrix colnames DEC2_UNIQ = major_purch daily_purch visits food doctor clothes
estout matrix(DEC2_UNIQ) using "Graphs and Tables/FAresulttables.xls", append

*Factor loadings 
matlist e(L)
matrix DEC2_LOAD = e(L)'
matrix colnames DEC2_LOAD = major_purch daily_purch visits food doctor clothes
estout matrix(DEC2_LOAD) using "Graphs and Tables/FAresulttables.xls", append

*Scoring coefficients
matrix colnames DEC2_SC = major_purch daily_purch visits food doctor clothes
estout matrix(DEC2_SC) using "Graphs and Tables/FAresulttables.xls", append

*eigenvalues
matlist e(Ev)
matrix DEC2_EV = e(Ev)
estout matrix(DEC2_EV) using "Graphs and Tables/FAresulttables.xls", append




*DOMESTIC VIOLENCE ACCEPTANCE
*Uses variables as is where 1=believes domestic violence is justified.
polychoric beatjust1 beatjust2 beatjust3 beatjust4 beatjust5 beatjust6 [pw=expan_indiv]
display r(N)
global N = r(N)
matrix Q = r(R)

*Means and sds
mean beatjust1 beatjust2 beatjust3 beatjust4 beatjust5 beatjust6 [pw=expan_indiv]
matrix mean = r(table)[1,1...]
tabstat beatjust1 beatjust2 beatjust3 beatjust4 beatjust5 beatjust6 [aw=expan_indiv], statistics(sd) save
matrix sd = r(StatTotal)
factormat Q, n($N) means(mean) sds(sd)

alpha beatjust1 beatjust2 beatjust3 beatjust4 beatjust5 beatjust6

predict factor1_dv
label var factor1_dv "Domestic violence justification factor"


*Save scoring coeff. 
matlist r(scoef)
matrix DV_SC = r(scoef)'


*estout results
*correlation matrix
matlist e(C)
matrix DV_CORR = e(C)
matrix rownames DV_CORR = burn_food negl_child argue talk_men waste_money refuse_sex
matrix colnames DV_CORR = burn_food negl_child argue talk_men waste_money refuse_sex
estout matrix(DV_CORR) using "Graphs and Tables/FAresulttables.xls", append

*uniqueness
matlist e(Psi)
matrix DV_UNIQ = e(Psi)
matrix colnames DV_UNIQ = burn_food negl_child argue talk_men waste_money refuse_sex
estout matrix(DV_UNIQ) using "Graphs and Tables/FAresulttables.xls", append

*Factor loadings
matlist e(L)
matrix DV_LOAD = e(L)'
matrix colnames DV_LOAD = burn_food negl_child argue talk_men waste_money refuse_sex
estout matrix(DV_LOAD) using "Graphs and Tables/FAresulttables.xls", append

*Scoring coefficients
matrix colnames DV_SC = burn_food negl_child argue talk_men waste_money refuse_sex
estout matrix(DV_SC) using "Graphs and Tables/FAresulttables.xls", append

*eigenvalues
matlist e(Ev)
matrix DV_EV = e(Ev)
estout matrix(DV_EV) using "Graphs and Tables/FAresulttables.xls", append



*GENDER ROLE ATTITUDES
*Questions 6 and 8 have been reverse coded for harmony with the other variables. Uses ordinal forms of variables where 1=strongly agree and 5=strongly disagree. 
polychoric opinion1a opinion2a opinion3a opinion5a opinion6 opinion7a opinion8 opinion9a opinion10a opinion11a [pw=expan_indiv]
display r(N)
global N = r(N)
matrix Z = r(R)

*Means and sds
mean opinion1a opinion2a opinion3a opinion5a opinion6 opinion7a opinion8 opinion9a opinion10a opinion11a [pw=expan_indiv]
matrix mean = r(table)[1,1...]
tabstat opinion1a opinion2a opinion3a opinion5a opinion6 opinion7a opinion8 opinion9a opinion10a opinion11a [aw=expan_indiv], statistics(sd) save
matrix sd = r(StatTotal)
factormat Z, n($N) means(mean) sds(sd)

alpha opinion1a opinion2a opinion3a opinion5a opinion6 opinion7a opinion8 opinion9a opinion10a opinion11a

predict factor1_genderatt

label var factor1_genderatt "Gender Role Attitudes Factor"

*Save scoring coeff. 
matlist r(scoef)
matrix ATT_SC = r(scoef)'

*estout results
*correlation matrix
matlist e(C)
matrix ATT_CORR = e(C)
matrix rownames ATT_CORR = women_work helpchild helpchores girlsprepjobs work_badmom financauton work_badwife leadership equal_school equal_treat
matrix colnames ATT_CORR = women_work helpchild helpchores girlsprepjobs work_badmom financauton work_badwife leadership equal_school equal_treat
estout matrix(ATT_CORR) using "Graphs and Tables/FAresulttables.xls", append

*uniqueness
matlist e(Psi)
matrix ATT_UNIQ = e(Psi)
matrix colnames ATT_UNIQ = women_work helpchild helpchores girlsprepjobs work_badmom financauton work_badwife leadership equal_school equal_treat
estout matrix(ATT_UNIQ) using "Graphs and Tables/FAresulttables.xls", append

*Factor loadings 
matlist e(L)
matrix ATT_LOAD = e(L)'
matrix colnames ATT_UNIQ = women_work helpchild helpchores girlsprepjobs work_badmom financauton work_badwife leadership equal_school equal_treat
estout matrix(ATT_LOAD) using "Graphs and Tables/FAresulttables.xls", append

*Scoring coefficients
matrix colnames ATT_SC = women_work helpchild helpchores girlsprepjobs work_badmom financauton work_badwife leadership equal_school equal_treat
estout matrix(ATT_SC) using "Graphs and Tables/FAresulttables.xls", append

*eigenvalues
matlist e(Ev)
matrix ATT_EV = e(Ev)
estout matrix(ATT_EV) using "Graphs and Tables/FAresulttables.xls", append


*rename factor1 to factor
rename factor1_dv factor_dv
rename factor1_genderatt factor_genderatt
rename factor1_mobil factor_mobil
rename factor1_decision factor_decision

save "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", replace

