/****************************************************************************
For WB GDFD project: Syrian Refugee Adolescents in Jordan.
This DO file runs regressions and creates coefplots for gender role attitudes, gendered behaviors as dependent variables
Created: 2020.12.11
Last updated: 2022.03.23
Version 12 CK
*****************************************************************************/

estimates clear

set scheme s1mono
*ssc install coefplot

use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear

***Globals for controls
global par_char i.mteducst i.fteducst i.dwealth i.ftempst

global geo i.urb_rural_camps c.clust_ses c.schldist_cluster 

************************************************************************
* No controls
************************************************************************

****Nationality
foreach var of varlist factor_* {
reg `var' i.nationalitya if miss_`var'==0 [pw=expan_indiv], vce(cluster currcluster)

estimates store e_nat_`var'	
}

****Age group by nationalitiy
foreach var of varlist factor_* {
foreach num of numlist 400 405 {	
reg `var' i.adolescent if miss_`var'==0 & nationalitya==`num' [pw=expan_indiv], vce(cluster currcluster)

estimates store e_nage_`var'_`num'	
}
}

****Sex by age group and nationality
foreach var of varlist factor_genderatt {
foreach num of numlist 0/1 {
foreach num2 of numlist 400 405 {		
reg `var' i.sex if miss_`var'==0 & adolescent==`num' & nationalitya==`num2' [pw=expan_indiv], vce(cluster currcluster)

estimates store e_sage_ga_`num'_`num2'	
}
}
}


****Nationality by sex and age
foreach var of varlist factor_genderatt {
foreach num of numlist 0/1 {
foreach num2 of numlist 1/2 {		
reg `var' i.nationalitya if miss_`var'==0 & adolescent==`num' & sex==`num2' [pw=expan_indiv], vce(cluster currcluster)

estimates store e_sagenat_ga_`num'_`num2'	
}
}
}

****Nationality by age - female only 
foreach var of varlist factor_* {
foreach num of numlist 0/1 {
reg `var' i.nationalitya if miss_`var'==0 & adolescent==`num' & sex==2 [pw=expan_indiv], vce(cluster currcluster)

estimates store e_f_`var'_`num'	
}
}
****Nationality - female only - total (adolescents & non)
foreach var of varlist factor_* {
	reg `var' i.nationalitya if miss_`var'==0 & sex==2 [pw=expan_indiv], vce(cluster currcluster)
	
estimates store e_f_`var'_t
}

************************************************************************
* With controls
************************************************************************

la def Lnationalitya 400 "Jordanian" 405 "Syrian", modify

*Graph with subgroups 

****Age group by nationalitiy
foreach var of varlist factor_* {
foreach num of numlist 400 405 {	
reg `var' i.adolescent $par_char $geo   if miss_`var'==0 & nationalitya==`num' [pw=expan_indiv], vce(cluster currcluster)

estimates store ec_nac_`var'_`num'	
}
}

*Graphing age group by nationality
foreach num of numlist 400 405 {

*Labels for figure titles	
levelsof nationalitya, local(levels)
local lbe: value label nationalitya

foreach l of local levels {
local f`l' : label `lbe' `l'	
}
*Graph
coefplot (ec_nac_factor_genderatt_`num' \ ec_nac_factor_dv_`num' \ ec_nac_factor_decision_`num' \ ///
ec_nac_factor_mobil_`num'), aseq mlabel() ///
 keep(*nationalitya* *adolescent* *sex*) swapnames coeflabels(ec_nac_factor_genderatt_`num'= "Gender role att." ec_nac_factor_dv_`num'= "Domestic violence" ec_nac_factor_decision_`num'= "Decision making" ec_nac_factor_mobil_`num'= "Mobility") ///
 xscale(range(-1.5(.5).5))  ///
xline(0) xtick(-1.5(.5).5) xlabel(-1.5(.5).5) xtitle("Adolescent coefficient") title("`f`num'' ")

graph save "Graphs and Tables/coefplot_ac_`num'.gph", replace
graph export "Graphs and Tables/coefplot_ac_`num'.png", replace width(1500) 

}

graph combine "Graphs and Tables/coefplot_ac_400.gph" "Graphs and Tables/coefplot_ac_405.gph"

graph save "Graphs and Tables/coefplot_ac.gph", replace
graph export "Graphs and Tables/coefplot_ac.png", replace width(1500) 


****Sex by age group and nationality
foreach var of varlist factor_genderatt {
foreach num of numlist 0/1 {
foreach num2 of numlist 400 405 {		
reg `var' i.sex $par_char $geo   if miss_`var'==0 & adolescent==`num' & nationalitya==`num2' [pw=expan_indiv], vce(cluster currcluster)

estimates store ec_sagec_ga_`num'_`num2'	
}
}
}

*Graphing sex by age group and nationality
coefplot (ec_sagec_ga_0_400 \ ec_sagec_ga_1_400 \ ec_sagec_ga_0_405 \ ec_sagec_ga_1_405), aseq mlabel() ///
 keep(*nationalitya* *adolescent* *sex*) swapnames coeflabels(ec_sagec_ga_1_400= "Jordanian Adolescents" ec_sagec_ga_0_400= "Jordanian Adults" ec_sagec_ga_1_405= "Syrian Adolescents" ec_sagec_ga_0_405= "Syrian Adults" ) ///
 xscale(range(-.25(.25).75))  ///
xline(0) xtick(-.25(.25).75) xlabel(-.25(.25).75) xtitle("Female coefficient") title("Gender role attitudes")

graph save "Graphs and Tables/coefplot_sagec.gph", replace
graph export "Graphs and Tables/coefplot_sagec.png", replace width(1500) 




****Nationality
foreach var of varlist factor_genderatt {
reg `var' i.nationalitya $par_char $geo   if miss_`var'==0  [pw=expan_indiv], vce(cluster currcluster)

estimates store ec_nat_`var'	
}


****Nationality for women
foreach var of varlist factor_* {
reg `var' i.nationalitya $par_char $geo   if miss_`var'==0 & sex==2 [pw=expan_indiv], vce(cluster currcluster)

estimates store ec_nat_`var'_f	
}


****Nationality by sex and age
foreach var of varlist factor_genderatt {
foreach num of numlist 0/1 {
foreach num2 of numlist 1/2 {		
reg `var' i.nationalitya $par_char $geo if miss_`var'==0 & adolescent==`num' & sex==`num2' [pw=expan_indiv], vce(cluster currcluster)

estimates store ec_sagenat_ga_`num'_`num2'	
}
}
}

*Graphing nationality by age group and sex
coefplot (ec_sagenat_ga_0_1 \ ec_sagenat_ga_0_2 \ ec_sagenat_ga_1_1 \ ec_sagenat_ga_1_2 \ ec_nat_factor_genderatt), aseq mlabel() ///
 keep(*nationalitya* *adolescent* *sex*) swapnames coeflabels(ec_sagenat_ga_1_1= "Male Adolescents" ec_sagenat_ga_0_1= "Male Adults" ec_sagenat_ga_1_2= "Female Adolescents" ec_sagenat_ga_0_2= "Female Adults" ec_nat_factor_genderatt="All") ///
 xscale(range(-.25(.25).75))  ///
xline(0) xtick(-.25(.25).75) xlabel(-.25(.25).75) xtitle("Syrian coefficient") title("Gender role attitudes")

graph save "Graphs and Tables/coefplot_sagenatc.gph", replace
graph export "Graphs and Tables/coefplot_sagenatc.png", replace width(1500) 


****Nationality by age - female only 
foreach var of varlist factor_* {
foreach num of numlist 0/1 {
reg `var' i.nationalitya $par_char $geo   if miss_`var'==0 & adolescent==`num' & sex==2 [pw=expan_indiv], vce(cluster currcluster)

estimates store ec_f_`var'_`num'	
}
}

*Graphing nationality by age group
foreach num of numlist 0 1 {

*Labels for figure titles	
levelsof adolescent, local(levels)
local lbe: value label adolescent

foreach l of local levels {
local f`l' : label `lbe' `l'	
}
*Graph
coefplot (ec_f_factor_genderatt_`num' \ ec_f_factor_dv_`num' \ ec_f_factor_decision_`num' \ ///
ec_f_factor_mobil_`num'), aseq mlabel() ///
 keep(*nationalitya* *adolescent* *sex*) swapnames coeflabels(ec_f_factor_genderatt_`num'= "Gender role att." ec_f_factor_dv_`num'= "Domestic violence" ec_f_factor_decision_`num'= "Decision making" ec_f_factor_mobil_`num'= "Mobility") ///
 xscale(range(-.75(.25).5))  ///
xline(0) xtick(-.75(.25).5) xlabel(-.75(.25).5) xtitle("Syrian coefficient") title("Female ""`f`num'' " )

graph save "Graphs and Tables/coefplot_nac_`num'.gph", replace
graph export "Graphs and Tables/coefplot_nac_`num'.png", replace width(1500) 

}

*Graph total
coefplot (ec_nat_factor_genderatt_f \ ec_nat_factor_dv_f \ ec_nat_factor_decision_f \ ///
ec_nat_factor_mobil_f), aseq mlabel() ///
 keep(*nationalitya* *adolescent* *sex*) swapnames coeflabels(ec_nat_factor_genderatt_f= "Gender role att." ec_nat_factor_dv_f= "Domestic violence" ec_nat_factor_decision_f= "Decision making" ec_nat_factor_mobil_f= "Mobility") ///
 xscale(range(-.75(.25).5))  ///
xline(0) xtick(-.75(.25).5) xlabel(-.75(.25).5) xtitle("Syrian coefficient") title("Female total")

graph save "Graphs and Tables/coefplot_nac_f.gph", replace
graph export "Graphs and Tables/coefplot_nac_f.png", replace width(1500) 

graph combine "Graphs and Tables/coefplot_nac_0.gph" "Graphs and Tables/coefplot_nac_1.gph" "Graphs and Tables/coefplot_nac_f.gph"

graph save "Graphs and Tables/coefplot_n_gbc.gph", replace
graph export "Graphs and Tables/coefplot_n_gbc.png", replace width(1500) 


************************
*estout results to Excel
************************* 

*Figure 2: All 4 outcomes, with and w/o controls, age by nationality
*Jordanians
esttab e_nage_factor_mobil_400 ec_nac_factor_mobil_400 e_nage_factor_decision_400 ec_nac_factor_decision_400 e_nage_factor_dv_400 ec_nac_factor_dv_400 e_nage_factor_genderatt_400 ec_nac_factor_genderatt_400 using "Graphs and Tables/coefplottables.csv", order(1.adolescent 2.mteducst 3.mteducst 4.mteducst 5.mteducst  2.fteducst 3.fteducst 4.fteducst 5.fteducst  2.ftempst 3.ftempst 5.ftempst 2.urb_rural_camps 9.urb_rural_camps wlth_cluster) cells(b(star fmt(%9.3f)) se(par))stats(N r2, fmt(%9.0g %9.3g) labels("N obs." "R-sq.")) label nobase noomit refcat(2.mteducst "Mother's ed: illit. omit." 2.fteducst "Father's ed: illit. omit." 2.ftempst "Father's emp status: wage worker omit." 2.urb_rural_camps "Geography: urban omit." 2.wlth_cluster "Cluster level wealth: 1st (poorest) decile omit.", nolabel) mlabel ("Mobility (no controls)" "Mobility" "Decision-making (no controls)" "Decision-making" "DV acceptance (no controls)" "DV acceptance" "GRAs (no controls)" "GRAs") title("Figure 2 Corresponding Table: Jordanians")replace

*Syrians
esttab e_nage_factor_mobil_405 ec_nac_factor_mobil_405 e_nage_factor_decision_405 ec_nac_factor_decision_405 e_nage_factor_dv_405 ec_nac_factor_dv_405 e_nage_factor_genderatt_405 ec_nac_factor_genderatt_405 using "Graphs and Tables/coefplottables.csv", order(1.adolescent 2.mteducst 3.mteducst 4.mteducst 5.mteducst  2.fteducst 3.fteducst 4.fteducst 5.fteducst  2.ftempst 3.ftempst 5.ftempst 2.urb_rural_camps 9.urb_rural_camps wlth_cluster) cells(b(star fmt(%9.3f)) se(par)) stats(N r2, fmt(%9.0g %9.3g) labels("N obs." "R-sq.")) label nobase noomit refcat(2.mteducst "Mother's ed: illit. omit." 2.fteducst "Father's ed: illit. omit." 2.ftempst "Father's emp status: wage worker omit." 2.urb_rural_camps "Geography: urban omit." 2.wlth_cluster "Cluster level wealth: 1st (poorest) decile omit.", nolabel) mlabel ("Mobility (no controls)" "Mobility" "Decision-making (no controls)" "Decision-making" "DV acceptance (no controls)" "DV acceptance" "GRAs (no controls)" "GRAs") title("Figure 2 Corresponding Table: Syrians") append

*Figure 3: GRAs as outcome, with and w/o controls, sex by age group & nationality
esttab e_sage_ga_0_400 ec_sagec_ga_0_400 e_sage_ga_1_400 ec_sagec_ga_1_400 e_sage_ga_0_405 ec_sagec_ga_0_405 e_sage_ga_1_405 ec_sagec_ga_1_405 using "Graphs and Tables/coefplottables.csv", order(2.sex 2.mteducst 3.mteducst 4.mteducst 5.mteducst  2.fteducst 3.fteducst 4.fteducst 5.fteducst  2.ftempst 3.ftempst 5.ftempst 2.urb_rural_camps 9.urb_rural_camps wlth_cluster)  cells(b(star fmt(%9.3f)) se(par)) stats(N r2, fmt(%9.0g %9.3g) labels("N obs." "R-sq.")) label nobase noomit refcat(2.mteducst "Mother's ed: illit. omit." 2.fteducst "Father's ed: illit. omit." 2.ftempst "Father's emp status: wage worker omit." 2.urb_rural_camps "Geography: urban omit." 2.wlth_cluster "Cluster level wealth: 1st (poorest) decile omit.", nolabel) mlabel("Jordanian adults (no controls)" "Jordanian adults" "Jordanian adolescents (no controls)" "Jordanian adolescents" "Syrian adults (no controls)" "Syrian adults" "Syrian adolescents (no controls)" "Syrian adolescents") title("Figure 3 Corresponding Table") append 

*Figure 4: GRAs as outcome, with and w/o controls, nationality by age group & sex
esttab e_sagenat_ga_0_1 ec_sagenat_ga_0_1 e_sagenat_ga_0_2 ec_sagenat_ga_0_2 e_sagenat_ga_1_1 ec_sagenat_ga_1_1 e_sagenat_ga_1_2 ec_sagenat_ga_1_2 using "Graphs and Tables/coefplottables.csv", order(405.nationalitya 2.mteducst 3.mteducst 4.mteducst 5.mteducst  2.fteducst 3.fteducst 4.fteducst 5.fteducst  2.ftempst 3.ftempst 5.ftempst 2.urb_rural_camps 9.urb_rural_camps wlth_cluster) cells(b(star fmt(%9.3f)) se(par)) stats(N r2, fmt(%9.0g %9.3g) labels("N obs." "R-sq.")) label nobase noomit refcat(2.mteducst "Mother's ed: illit. omit." 2.fteducst "Father's ed: illit. omit." 2.ftempst "Father's emp status: wage worker omit." 2.urb_rural_camps "Geography: urban omit." 2.wlth_cluster "Cluster level wealth: 1st (poorest) decile omit.", nolabel) mlabel("Adult males (no controls)" "Adult males" "Adult females (no controls)" "Adult females" "Adolescent males (no controls)" "Adolescent males" "Adolescent females (no controls)" "Adolescent females") title("Figure 4 Corresponding Table") append

*Figure 5: All 4 outcomes, with and w/o controls, nationality, 3 subgroups
*Female total
esttab e_f_factor_mobil_t	ec_nat_factor_mobil_f e_f_factor_decision_t ec_nat_factor_decision_f e_f_factor_dv_t ec_nat_factor_dv_f e_f_factor_genderatt_t ec_nat_factor_genderatt_f using "Graphs and Tables/coefplottables.csv", order(405.nationalitya 2.mteducst 3.mteducst 4.mteducst 5.mteducst  2.fteducst 3.fteducst 4.fteducst 5.fteducst  2.ftempst 3.ftempst 5.ftempst 2.urb_rural_camps 9.urb_rural_camps wlth_cluster) cells(b(star fmt(%9.3f)) se(par)) stats(N r2, fmt(%9.0g %9.3g) labels("N obs." "R-sq.")) label nobase noomit refcat(2.mteducst "Mother's ed: illit. omit." 2.fteducst "Father's ed: illit. omit." 2.ftempst "Father's emp status: wage worker omit." 2.urb_rural_camps "Geography: urban omit." 2.wlth_cluster "Cluster level wealth: 1st (poorest) decile omit.", nolabel) mlabel("Mobility (no controls)" "Mobility" "Decision-making (no controls)" "Decision-making" "DV acceptance (no controls)" "DV acceptance" "GRAs (no controls)" "GRAs") title("Figure 5 Corresponding Table: Female Total") append

*Female adolescent
esttab e_f_factor_mobil_1 ec_f_factor_mobil_1 e_f_factor_decision_1 ec_f_factor_decision_1 e_f_factor_dv_1 ec_f_factor_dv_1 e_f_factor_genderatt_1 ec_f_factor_genderatt_1 using "Graphs and Tables/coefplottables.csv", order(405.nationalitya 2.mteducst 3.mteducst 4.mteducst 5.mteducst  2.fteducst 3.fteducst 4.fteducst 5.fteducst  2.ftempst 3.ftempst 5.ftempst 2.urb_rural_camps 9.urb_rural_camps wlth_cluster) cells(b(star fmt(%9.3f)) se(par)) stats(N r2, fmt(%9.0g %9.3g) labels("N obs." "R-sq.")) label nobase noomit refcat(2.mteducst "Mother's ed: illit. omit." 2.fteducst "Father's ed: illit. omit." 2.ftempst "Father's emp status: wage worker omit." 2.urb_rural_camps "Geography: urban omit." 2.wlth_cluster "Cluster level wealth: 1st (poorest) decile omit.", nolabel) mlabel("Mobility (no controls)" "Mobility" "Decision-making (no controls)" "Decision-making" "DV acceptance (no controls)" "DV acceptance" "GRAs (no controls)" "GRAs") title("Figure 5 Corresponding Table: Female Adolescents") append

*Female non-adolescent
esttab e_f_factor_mobil_0 ec_f_factor_mobil_0 e_f_factor_decision_0 ec_f_factor_decision_0 e_f_factor_dv_0 ec_f_factor_dv_0 e_f_factor_genderatt_0 ec_f_factor_genderatt_0 using "Graphs and Tables/coefplottables.csv", order(405.nationalitya 2.mteducst 3.mteducst 4.mteducst 5.mteducst  2.fteducst 3.fteducst 4.fteducst 5.fteducst  2.ftempst 3.ftempst 5.ftempst 2.urb_rural_camps 9.urb_rural_camps wlth_cluster) cells(b(star fmt(%9.3f)) se(par)) stats(N r2, fmt(%9.0g %9.3g) labels("N obs." "R-sq.")) label nobase noomit refcat(2.mteducst "Mother's ed: illit. omit." 2.fteducst "Father's ed: illit. omit." 2.ftempst "Father's emp status: wage worker omit." 2.urb_rural_camps "Geography: urban omit." 2.wlth_cluster "Cluster level wealth: 1st (poorest) decile omit.", nolabel) mlabel("Mobility (no controls)" "Mobility" "Decision-making (no controls)" "Decision-making" "DV acceptance (no controls)" "DV acceptance" "GRAs (no controls)" "GRAs") title("Figure 5 Corresponding Table: Female Non-Adolescents") append



************************************************************************
* With controls - FHH SA
************************************************************************

gen female_head=1 if pn==1 & sex==2
replace female_head=0 if pn==1 & sex==1

egen fhh=max(female_head), by(hhid)


****Age group by nationalitiy
foreach var of varlist factor_* {
foreach num of numlist 400 405 {	
reg `var' i.adolescent $par_char $geo  i.fhh  if miss_`var'==0 & nationalitya==`num' [pw=expan_indiv], vce(cluster currcluster)

}
}

****Sex by age group and nationality
foreach var of varlist factor_genderatt {
foreach num of numlist 0/1 {
foreach num2 of numlist 400 405 {		
reg `var' i.sex $par_char $geo  i.fhh if miss_`var'==0 & adolescent==`num' & nationalitya==`num2' [pw=expan_indiv], vce(cluster currcluster)

}
}
}


****Nationality
foreach var of varlist factor_genderatt {
reg `var' i.nationalitya $par_char $geo  i.fhh if miss_`var'==0  [pw=expan_indiv], vce(cluster currcluster)

}


****Nationality for women
foreach var of varlist factor_* {
reg `var' i.nationalitya $par_char $geo  i.fhh if miss_`var'==0 & sex==2 [pw=expan_indiv], vce(cluster currcluster)

}


****Nationality by sex and age
foreach var of varlist factor_genderatt {
foreach num of numlist 0/1 {
foreach num2 of numlist 1/2 {		
reg `var' i.nationalitya $par_char $geo i.fhh if miss_`var'==0 & adolescent==`num' & sex==`num2' [pw=expan_indiv], vce(cluster currcluster)

}
}
}


****Nationality by age - female only 
foreach var of varlist factor_* {
foreach num of numlist 0/1 {
reg `var' i.nationalitya $par_char $geo  i.fhh  if miss_`var'==0 & adolescent==`num' & sex==2 [pw=expan_indiv], vce(cluster currcluster)

}
}

