/**********************************************************************************
This do file was created by IP on 5.29.20 to prep and clean JLMPS 2016 data. Includes preparation of outcome variables.
Version: v19 
Last updated: 2022.03.23 CGK
**********************************************************************************/

*Pull in school distance
use "Data/JLMPS 2016 xs v1.1 pt 2.dta", clear

keep indid q320_1_c

save "Data/school distance data.dta", replace

use "Data/JLMPS 2016 xs v1.1 pt 1.dta", clear

merge m:1 indid using "Data/school distance data.dta"
drop _merge

*------------------------------------------------------------------------------*

*drop all those not Syrian, Jordanian, or Palestinian
drop if nationality!=400 & nationality!=405 & nationality!=408

******************
*Gender roles and behaviors
******************


*rename some fnlsay*marr variables (originally goes 1, 2, 3, 4, 5, 6, 7, 9, 10)
rename fnl*9 fnl*8
rename fnl*10 fnl*9

*replacing NAs with missings
foreach num of numlist 1/9 {
replace fnlsaymarr`num'=. if fnlsaymarr`num'==7	
}

foreach num of numlist 1/9 {
replace fnlsayumarr`num'=. if fnlsayumarr`num'==10
}

replace q8306_1=. if q8306_1==99
replace q8306_2=. if q8306_2==99
replace q8306_3=. if q8306_3==99
replace q8306_4=. if q8306_4==99

*Replacing year of first birth with missing if not known
replace yrbirth1=. if yrbirth1==9998

*consolidate fnlsayumarr responses: mother, father, and parents together in one category (2). Grandparents, siblings, children, and others all "other" (4)

*1=self, 2=parents, 3=self and parents, 4=others
foreach num of numlist 1/9 {

replace fnlsayumarr`num'=2 if fnlsayumarr`num'==3 | fnlsayumarr`num'==4
replace fnlsayumarr`num'=3 if fnlsayumarr`num'==5
replace fnlsayumarr`num'=4 if fnlsayumarr`num'==6 | fnlsayumarr`num'==7 | fnlsayumarr`num'==8 | fnlsayumarr`num'==9
	
}
la def decision2 1 "Self only" 2 "Parents" 3 "Self and parents" 4 "Others", modify

*consolidate fnlsaymarr responses for others
foreach num of numlist 1/9 {

replace fnlsaymarr`num'=4 if fnlsaymarr`num'==5 | fnlsaymarr`num'==6
}

la def decision1 4 "Others", modify

*creating binary variables for the decision making questions in 8.3 (any involvement yes/no). This is ALL women, married and unmarried, in harmonized variables

foreach num of numlist 1/9 {
gen fnlsayall`num'=.

*Married -- self, self and husband, self and husband and inlaws. Unmarried -- self or self and parents
replace fnlsayall`num'=1 if fnlsaymarr`num'==1 | fnlsaymarr`num'==3 | fnlsaymarr`num'==5 | fnlsayumarr`num'==1 | fnlsayumarr`num'==3

* Married -- husband, in laws, others. Unmarried -- Parents or Others
replace fnlsayall`num'=0 if fnlsaymarr`num'==2 | fnlsaymarr`num'==4 | fnlsaymarr`num'==6 | fnlsayumarr`num'==2 | fnlsayumarr`num'==4

}

la define Lfnlsayall 1 "Involved" 0 "Not involved"
la val fnlsayall1-fnlsayall9 Lfnlsayall

la variable fnlsayall1 "All: Who decides -Major household items"
la variable fnlsayall2 "All: Who decides -Daily needs"
la variable fnlsayall3 "All: Who decides -Visits to family/friends"
la variable fnlsayall4 "All: Who decides -Types of daily food"
la variable fnlsayall5 "All: Who decides -Going to doctor"
la variable fnlsayall6 "All: Who decides -Buying personal clothes"
la variable fnlsayall7 "All: Who decides -Taking child to doctor"
la variable fnlsayall8 "All: Who decides -Sending children to school daily"
la variable fnlsayall9 "All: Who decides -Buying clothes for children"

*recode 8308 variables as 0/1 instead of 1/2, don't know to no
clonevar c_q8308_1=q8308_1
clonevar c_q8308_2=q8308_2

replace c_q8308_1=0 if q8308_1==2
replace c_q8308_1=0 if q8308_1==98
replace c_q8308_2=0 if q8308_2==2
replace c_q8308_2=0 if q8308_2==98

la val c_q8308_* noyes

*female binary variable
gen female=.
replace female=1 if sex==2
replace female=0 if sex==1

*Reverse coding of items e and g in 12.3 gender attitudes to standardize direction of agreement across items

foreach num of numlist 1/3 5 7 9/11 {
	recode opinion`num' (1=5) (2=4) (3=3) (4=2) (5=1) , gen(opinion`num'a)
}


*Domestic violence as 0/1
foreach num of numlist 1/6 {
	replace beatjust`num'=1 if q8309_`num'==1
	replace beatjust`num'=0 if q8309_`num'==2
	}

la def Lbeatjust 1 "Justified" 0 "Not justified"
la val beatjust1-beatjust6 Lbeatjust

*In any situation
gen beatjustever=1 if beatjust1==1 | beatjust2==1 | beatjust3==1 | beatjust4==1 | beatjust5==1 | beatjust6==1

replace beatjustever=0 if beatjust1!=1 & beatjust2!=1 & beatjust3!=1 & beatjust4!=1 & beatjust5!=1 & beatjust6!=1 &  beatjust1!=. & beatjust2!=. & beatjust3!=. & beatjust4!=. & beatjust5!=. & beatjust6!=.

la def Lbeatjustever 1 "Never Justified" 0 "Justified"
la val beatjustever Lbeatjustever
la var beatjustever "Husb justif beat his wife in one more situation"

*creating three-category variables from the mobility questions on going alone to certain places (can go alone with or without informing/can go alone with permission/cannot go alone)
foreach var of varlist q8306_1 q8306_2 q8306_3 q8306_4 {
	gen `var't=.
	replace `var't=0 if `var'==4 | `var'==98
	replace `var't=1 if `var'==2
	replace `var't=2 if `var'==1 | `var'==3
}

rename q8306_1t q8306t1
rename q8306_2t q8306t2
rename q8306_3t q8306t3
rename q8306_4t q8306t4

label define Lmobilitycategoricals 0 "Cannot go alone" 1 "Can go alone--with permission" 2 "Can go alone--with or without informing", modify
label val q8306t1 q8306t2 q8306t3 q8306t4 Lmobilitycategoricals

label variable q8306t1 "Mobility: local market (three categories)"
label variable q8306t2 "Mobility: doctor (three categories)"
label variable q8306t3 "Mobility: child's doctor (three categories)"
label variable q8306t4 "Mobility: visits (three categories)"

*recode father and mother in home as dummies for ease of use later
replace q213=0 if q213==2
replace q214=0 if q214==2

******************
*Other Covariates
******************

*Age-10 and square
gen age_m10=age-10
gen age_m10_sq=age_m10*age_m10

*binary variable for adolescent
gen adolescent=.
replace adolescent=0 if agegrp2!=.
*10-14 or 15-19
replace adolescent=1 if agegrp2==3 | agegrp2==4
la define Ladolescent 0 "Adult" 1 "Adolescent"
la val adolescent Ladolescent

*new educ1d variable that combines highest three levels
gen educ1da=.
replace educ1da=educ1d if educ1d==1 | educ1d==2 | educ1d==3 | educ1d==4
replace educ1da=5 if educ1d==5 | educ1d==6 | educ1d==7

*places current students at the post-secondary level into the post secondary category (even if they have not completed the level)
replace educ1da=5 if educ1da==4 & student==1

la def Leduc1da 1 "Illiterate" 2 "Read & Write" 3 "Basic" 4 "Secondary" 5 "Above Secondary" 
la val educ1da Leduc1da

*Nationality groups. Palestinians included as Jordanians. 

gen nationalitya=nationality
replace nationalitya=400 if nationalitya==408
la define Lnationalitya 400 "Jordanian and Palestinian" 405 "Syrian"
la val nationalitya Lnationalitya

egen group=group(sex nationalitya)

la define Lgroup 1 "Jordanian Men" 2 "Syrian Men" 3 "Jordanian Women" 4 "Syrian Women"
la val group Lgroup

*Host community vs. camps

clonevar host_camps=urb_rural_camps
replace host_camps=1 if host_camps==2

la def Lhost_camps 1 "Host community" 9 "Camp", modify
la val host_camps Lhost_camps


*Father's employment collapsing
recode ftempst (4 6=5)

*geographic clusters
egen currcluster=group(gov district subdistrict locality)

*Persons per room in house
gen pperroom=hhsize/rooms



*cluster level (secondary plus sex)/sex pop
gen is_secwoman=0 if age>=20 & age<=59 & sex==2 & educ1d!=.
replace is_secwoman=1 if sex==2 & (educ1d==5 | educ1d==6 | educ1d==7)

gen is_secman=0 if age>=20 & age<=59 & sex==1 & educ1d!=.
replace is_secman=1 if sex==1 & (educ1d==5 | educ1d==6 | educ1d==7)


*cluster level formal workers/adult pop
gen isformal=0 if age>=15 & age<=59 & (uswrkst1==2 | uswrkst1==3 | usformal==0)
replace isformal=1 if age>=15 & age<=59 & (uswrkst1==1 & usformal==1)

*cluster level household chars
preserve

collapse (mean) schldist_cluster=q320_1_c (sd) wlthineq_cluster=wealth (mean) wlth_cluster=wealth (mean) pperroom_cluster=pperroom if pn==1 [aw=expan_hh], by(currcluster)

save "Data/cluster_hh_char.dta", replace

restore

*cluster level indiv chars
preserve
collapse (mean) propeducwoman_cluster=is_secwoman (mean) propeducmen_cluster=is_secman (mean) propformal_cluster=isformal [aw=expan_indiv], by(currcluster)

*Merge in HH char. 
merge 1:1 currcluster using "Data/cluster_hh_char.dta"
drop _merge

*Factor into an SES

factor wlthineq_cluster wlth_cluster pperroom_cluster propeducwoman_cluster propeducmen_cluster propformal_cluster, factor(1) 

predict clust_ses

save "Data/cluster_ind_char.dta", replace

restore

drop is_secwoman isformal is_secman

merge m:1 currcluster using "Data/cluster_ind_char.dta"
drop _merge



la var wlthineq_cluster "Cluster level wealth inequality"
la var wlth_cluster "Cluster level wealth"
la var pperroom_cluster "Cluster level persons per room"

la var propeducwoman_cluster "Cluster level proportion of women w/secondary+"
la var propeducmen_cluster "Cluster level proportion of men w/secondary+"
la var schldist_cluster "Cluster level average distance from primary school (in minutes)"
la var propformal_cluster "Cluster level proportion of adults formal workers"

la var clust_ses "Cluster level socio-economic status factor"

*Mother and father characteristic variables
*merge post-secondary into higher ed. w/university
replace mteducst=5 if mteducst==6
replace fteducst=5 if fteducst==6


la def Lfteducst 1 "Fth: Illiterate" 2 "Fth: Read & Write" 3 "Fth: Basic" 4 "Fth: Secondary" 5 "Fth: Higher Ed.", modify
la values fteducst Lfteducst
la def Lmteducst 1 "Mth: Illiterate" 2 "Mth: Read & Write" 3 "Mth: Basic " 4 "Mth: Secondary" 5 "Mth: Higher Ed." , modify
la values mteducst Lmteducst
la def Lftempst 1 "Fth: Waged employee" 2 "Fth: Employer" 3 "Fth: Self-employed" 5 "Fth: Non-employed", modify
la values ftempst Lftempst


************************************************************
*PREPARING OUTCOME VARIABLES
************************************************************

*Enrolled
tabu student

*variable for total number of hours spent on domestic work tasks in the last 7 days
foreach num of numlist 1/9 {
gen c_q4002_0`num'=0 if q4002a_0`num'==2	
replace c_q4002_0`num'=q4002b_0`num'+q4002b_0`num'/60 if q4002a_0`num'==1		
}

foreach num of numlist 10/12 {
gen c_q4002_`num'=0 if q4002a_`num'==2	| q4002a_`num'==98	
replace c_q4002_`num'=q4002b_`num'+q4002b_`num'/60 if q4002a_`num'==1		
}

*Domestic work, total*
sum domestic_hrs

*recoding binary variables for whether the respondent spent time on an activity in the last 7 days
foreach var of varlist q4002a_01-q4002a_12 {
	gen c_`var' = 0 if `var' == 98 | `var' == 2 
	replace c_`var' = 1 if `var' == 98 | `var' == 2 
	}

la val c_q4002a_* noyes



*condensing types of domestic work

*agriculture/subsistence work is q4002_01
replace c_q4002_01=c_q4002_01+c_q4002_02+c_q4002_03

label var c_q4002_01 "Hours spent last 7 days - Ag. and subsistence work"
drop c_q4002_02 c_q4002_03

replace c_q4002a_01=1 if c_q4002a_01==1 | c_q4002a_02==1 | c_q4002a_03==1
replace c_q4002a_01=0 if c_q4002a_01==0 & c_q4002a_02==0 & c_q4002a_03==0
label var c_q4002a_01 "Spent time last 7 days - Ag. and subsistence work"
drop c_q4002a_02 c_q4002a_03

*cooking and dishwashing is q4002b_04
replace c_q4002_04=c_q4002_04+c_q4002_05

label var c_q4002_04 "Hours spent last 7 days - Cooking and dishwashing"

*laundry and ironing and cleaning the house is q4002b_06
replace c_q4002_06=c_q4002_06+c_q4002_07

label var c_q4002_06 "Hours spent last 7 days - Laundry or ironing and cleaning house"

*caring for sick or elderly and caring for children
replace c_q4002_11=c_q4002_11+c_q4002_12

label var c_q4002_11 "Hours spent last 7 days - Caring for sick, elderly or children"
drop c_q4002_12


*condensing types of domestic work part 2: into five categories, combining agriculture/subsistence, firewood/fuel and construction into one category. This is for the graphs for readability
gen c_q4002d_01=c_q4002_01
gen c_q4002d_04=c_q4002_04
gen c_q4002d_06=c_q4002_06
gen c_q4002d_08=c_q4002_08
gen c_q4002d_09=c_q4002_09
gen c_q4002d_10=c_q4002_10
gen c_q4002d_11=c_q4002_11

replace c_q4002d_01=c_q4002d_01+c_q4002d_08+c_q4002d_09

save "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", replace
