/****************************************************************************
For WB GDFD project: Syrian Refugee Adolescents in Jordan.
This DO file creates multiple levels (self, family, communities) of factors
Created: 2020.11.13
Last updated: 2022.03.23
Version 11 CK
*****************************************************************************/

***********
*Mothers
***********

use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear

*keep needed variables
keep hhid pn factor*

*Switch identifier to be able to merge. 
rename pn mthcode

*Rename factor variables
rename factor_* mth_factor_*

save "Data/mother factor data.dta", replace

***********
*Fathers
***********

use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear

*keep needed variables
keep hhid pn factor_genderatt

*Switch identifier to be able to merge. 
rename pn fthcode

*Rename factor variables - only gender role attitudes
rename factor_* fth_factor_*

save "Data/father factor data.dta", replace

***********
*Merge
***********

use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear
*Merge on mother code and household id
merge m:1 mthcode hhid using "Data/mother factor data.dta"
tabu _merge

*Drop people who were not mothers
drop if _merge==2
rename _merge mother_merge

*Merge on father code and household id
merge m:1 fthcode hhid using "Data/father factor data.dta"
tabu _merge

*Drop people who were not mothers
drop if _merge==2
rename _merge father_merge

*Check	
sum *factor_dv *factor_genderatt *factor_mobil *factor_decision

sort hhid pn


*Check	
sum *factor_dv *factor_genderatt *factor_mobil *factor_decision

sort hhid pn
*browse hhid pn sex *dv 	

****************
*Mean factors--Syrian and Jordanian communities, by cluster
****************
*Weighted means

foreach var of varlist factor_genderatt factor_decision factor_dv factor_mobil {
		egen comm_`var'=wtmean(`var'), by(currcluster) weight(expan_indiv)
		sum comm_`var' [aw=expan_indiv]
		replace comm_`var'=(comm_`var'-r(mean))/r(sd)
}
	

****Replace with next-highest-ranked male or female
*fakes for easy loop
gen fth_factor_mobil=.
gen fth_factor_dv=.
gen fth_factor_decision=.

gen rank_m=pn if sex==1
gen rank_f=pn if sex==2

egen h_rank_m=min(rank_m), by(hhid)
egen h_rank_f=min(rank_f), by(hhid)


foreach var of varlist factor_* {
	gen h_r_m_`var'=`var' if pn==h_rank_m  
	gen h_r_f_`var'=`var' if pn==h_rank_f 

	replace fth_`var'=h_r_m_`var' if fth_`var'==.
	replace mth_`var'=h_r_f_`var' if mth_`var'==.
*Or community mean if still missing	
	replace fth_`var'=comm_`var' if fth_`var'==.
	replace mth_`var'=comm_`var' if mth_`var'==. 

	
*Mother difference from father	
	gen mth_diff_`var'=mth_`var'-fth_`var'
	
	}


*Drop fakes/extra
drop fth_factor_decision fth_factor_mobil fth_factor_dv	mth_diff_factor_decision mth_diff_factor_mobil mth_diff_factor_dv	 
drop h_r*
	
sum *factor*	
	
****Replace with mean for subgroup if missing
foreach var of varlist factor* {
	gen miss_`var'=0 if `var'!=.
	replace miss_`var'=1 if `var'==.
	
	foreach num1 of numlist 400 405 {
		foreach num2 of numlist 0 1 {
			foreach num3 of numlist 1 2 {
	sum `var' [aw=expan_indiv] if nationalitya==`num1' & adolescent==`num2' & sex==`num3'
	replace `var'=r(mean) if `var'==. & nationalitya==`num1' & adolescent==`num2' & sex==`num3'				
			}
		}
	}

}

	
	
*Label mother and father factors
label variable mth_factor_genderatt "Mth: Gender role attitudes factor"
label variable mth_factor_mobil "Mth: Mobility factor"
label variable mth_factor_dv "Mth: DV justification factor"
label variable mth_factor_decision "Mth: Decision-making factor"

label variable fth_factor_genderatt "Fth: Gender role attitudes factor"

label var mth_diff_factor_genderatt "Mother - father: Gender role attitudes"
	

*Label Syrian and Jordanian factors
label variable comm_factor_mobil "Community mobility factor"
label variable comm_factor_decision "Community decision-making factor"
label variable comm_factor_dv "Community DV justification factor"
label variable comm_factor_genderatt "Community gender role attitudes factor"

	
save "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", replace

