/****************************************************************************
Gender Dimensions of Forced Displacement WB paper
This DO file runs regressions on outcome variables (domestic work, access to healthcare, access to IT, school enrollment, educ attainment, LFP, unemployment)
Created: 2020.11.30 
Last modified: 2022.03.23
V27 CK
*****************************************************************************/

use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear

estimates clear 

sort indid
set seed 304723

*Ns for Table 1
tabu sex nationalitya if age>=10 & age<=19 & expan_indiv!=. & (marital==. |  marital==1)
tabu sex nationalitya if age>=20 & age<=24 & expan_indiv!=.
tabu sex nationalitya if age>=20 & age<. & expan_indiv!=.

*********
*Globals
*********

***Globals for controls
global par_char i.mteducst i.fteducst i.dwealth i.ftempst

global geo i.urb_rural_camps c.clust_ses c.schldist_cluster 

global age age_m10 age_m10_sq

global age_sex c.age_m10#i.sex c.age_m10_sq#i.sex

global ga factor_genderatt mth_factor_genderatt mth_diff_factor_genderatt comm_factor_genderatt

global ga_comm_nat c.comm_factor_genderatt#i.nationalitya 

global gb factor_dv mth_factor_dv comm_factor_dv  ///
factor_decision mth_factor_decision comm_factor_decision ///
factor_mobil mth_factor_mobil comm_factor_mobil 

global ga_sex i.sex#c.factor_genderatt i.sex#c.mth_factor_genderatt i.sex#c.mth_diff_factor_genderatt i.sex#c.comm_factor_genderatt

global dv_sex i.sex#c.factor_dv i.sex#c.mth_factor_dv i.sex#c.comm_factor_dv

global decision_sex i.sex#c.factor_decision i.sex#c.mth_factor_decision  i.sex#c.comm_factor_decision

global mobil_sex i.sex#c.factor_mobil i.sex#c.mth_factor_mobil i.sex#c.comm_factor_mobil

global ga_nat i.nationalitya#c.factor_genderatt i.nationalitya#c.mth_factor_genderatt i.nationalitya#c.mth_diff_factor_genderatt i.nationalitya#c.comm_factor_genderatt 

global dv_nat i.nationalitya#c.factor_dv i.nationalitya#c.mth_factor_dv i.nationalitya#c.comm_factor_dv 

global decision_nat i.nationalitya#c.factor_decision i.nationalitya#c.mth_factor_decision i.nationalitya#c.comm_factor_decision 

global mobil_nat i.nationalitya#c.factor_mobil i.nationalitya#c.mth_factor_mobil i.nationalitya#c.comm_factor_mobil


*************
*Universe - Adolescents in natal household
*************

*Adolescents only
keep if age>=10 & age<=19

*Responded to individual section
keep if expan_indiv!=.

*Only if still in natal household - operationalizing as unmarried
drop if marital>=2 & marital<.


****Stats: Correlations for footnote
corr factor_genderatt mth_factor_genderatt fth_factor_genderatt mth_diff_factor_genderatt comm_factor_genderatt if miss_factor_genderatt!=1 [aw=expan_indiv]


***********
*Outcomes as dependent variables 
***********
/* 

No controls

Model 1 -- Syrians v. Jordanians among girls
Model 2 -- Girls v. Boys among Syrians
Into appendix

Add controls 

Model 3 -- Syrians v. Jordanians among girls, GRA & GB
Model 4 -- Girls v. Boys among Syrians, GRA

Add GA

Model 5 -- Syrians v. Jordanians among girls, GRA
Model 6 -- Girls v. Boys among Syrians, GRA

Model 7 -- Syrians v. Jordanians among girls, GRA & GB

Model 8a -- Syrians v. Jordanians among girls, GRA & GB w/int. to test
Model 9a -- Girls v. Boys among Syrians, GRA w/int. to test

Model 8a -- Syrians v. Jordanians among girls, GRA & GB w/int. survive
Model 9a -- Girls v. Boys among Syrians, GRA w/int. survive



*/

****Domestic (care) work tobit

**No controls
*Model 1 -- 10-19 Syrians v. Jordanians among girls
tobit domestic_hrs i.nationalitya ///
if age>=10 & age<=19 & sex==2 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

estimates store domestic_hrs_1

*Model 2 -- 10-19 Girls v. Boys among Syrians
tobit domestic_hrs i.sex ///
 if age>=10 & age<=19 & nationalitya==405 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

estimates store domestic_hrs_2

**Add controls 

*Model 3 -- 10-19 Syrians v. Jordanians among girls
tobit domestic_hrs i.nationalitya $age ///
$par_char $geo ///
if age>=10 & age<=19 & sex==2 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

estimates store domestic_hrs_3


*Model 4 -- 10-19 Girls v. Boys among Syrians
tobit domestic_hrs i.sex $age $age_sex ///
$par_char $geo ///
if age>=10 & age<=19 & nationalitya==405 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

estimates store domestic_hrs_4



**Add GRA 

*Model 5 -- 10-19 Syrians v. Jordanians among girls, GRA 
tobit domestic_hrs i.nationalitya $age ///
$par_char $geo $ga ///
if age>=10 & age<=19 & sex==2 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

estimates store domestic_hrs_5


*Model 6 -- 10-19 Girls v. Boys among Syrians, GRA
tobit domestic_hrs i.sex $age $age_sex ///
$par_char $geo $ga ///
if age>=10 & age<=19 & nationalitya==405 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

estimates store domestic_hrs_6


**Add GB 

*Model 7 -- 10-19 Syrians v. Jordanians among girls, GRA & GB
tobit domestic_hrs i.nationalitya $age ///
$par_char $geo $ga $gb ///
if age>=10 & age<=19 & sex==2 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

estimates store domestic_hrs_7


**Add Int. to test 

*Model 8a -- 10-19 Syrians v. Jordanians among girls, GRA, GB, int
tobit domestic_hrs i.nationalitya $age ///
$par_char $geo $ga $gb $ga_nat $dv_nat $decision_nat $mobil_nat  ///
if age>=10 & age<=19 & sex==2 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

*Test
test 405.nationalitya#c.factor_genderatt 405.nationalitya#c.mth_factor_genderatt 405.nationalitya#c.mth_diff_factor_genderatt  405.nationalitya#c.comm_factor_genderatt 
*insig

test 405.nationalitya#c.factor_dv  405.nationalitya#c.mth_factor_dv  405.nationalitya#c.comm_factor_dv  
*sig

test 405.nationalitya#c.factor_decision  405.nationalitya#c.mth_factor_decision  405.nationalitya#c.comm_factor_decision 
*insig

test 405.nationalitya#c.factor_mobil  405.nationalitya#c.mth_factor_mobil  405.nationalitya#c.comm_factor_mobil
*insig


*Model 8b -- 10-19 Syrians v. Jordanians among girls, GRA, GB, int
tobit domestic_hrs i.nationalitya $age ///
$par_char $geo $ga $gb $dv_nat ///
if age>=10 & age<=19 & sex==2 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

estimates store domestic_hrs_8


*Graphing
coefplot (domestic_hrs_8), aseq mlabel() ///
 keep(405.nationalitya *genderatt* *decision* *mobil* *dv*) ///
 xscale(range(-15(5)10))  ///
 heading (factor_genderatt = "{bf: Gender role attitudes}"  factor_dv = "{bf: Justification of domestic violence}" factor_decision="{bf: Decision-making}" factor_mobil="{bf: Mobility}" 405.nationalitya#c.factor_dv="{bf: Interactions}") ///
xline(0) xtick(-15(5)10) xlabel(-15(5)10) xtitle("Coefficient: domestic work") title("Girls") rename (405.nationalitya = "Syrian (Jordanian omit.)")

graph save "Graphs and Tables/coefplot_dom_girls.gph", replace
graph export "Graphs and Tables/coefplot_dom_girls.png", replace width(1500) 





*Model 9a=9b -- 10-19 Girls v. Boys among Syrians, GRA int
tobit domestic_hrs i.sex $age $age_sex ///
$par_char $geo $ga $ga_sex ///
if age>=10 & age<=19 & nationalitya==405 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

*estimates store domestic_hrs_9

test 2.sex#c.factor_genderatt 2.sex#c.mth_factor_genderatt 2.sex#c.mth_diff_factor_genderatt  2.sex#c.comm_factor_genderatt
*insig 


*Graphing 
coefplot (domestic_hrs_6), aseq mlabel() ///
 keep(2.sex *genderatt*) ///
 xscale(range(-30(10)40))  ///
xline(0) xtick(-30(10)40) xlabel(-30(10)40) xtitle("Coefficient: domestic work") title("Syrians") rename(2.sex = "Female (male omit.)")


graph save "Graphs and Tables/coefplot_dom_syr.gph", replace
graph export "Graphs and Tables/coefplot_dom_syr.png", replace width(1500) 





*******************
***Logit model set
*******************

**No controls
*Model 1 -- 10-19 Syrians v. Jordanians among girls	
logit student i.nationalitya if age>=10 & age<=19 & sex==2 [pw=expan_indiv], vce(cluster currcluster)


est store student_1


*Model 2 -- 10-19 Girls v. Boys among Syrians
logit student i.sex  if age>=10 & age<=19 & nationalitya==405 [pw=expan_indiv], vce(cluster currcluster)


est store student_2

**Add controls 

*Model 3 -- 10-19 Syrians v. Jordanians among girls
logit student i.nationalitya $age $par_char $geo if age>=10 & age<=19 & sex==2 [pw=expan_indiv], vce(cluster currcluster)


est store student_3

*Model 4 -- 10-19 Girls v. Boys among Syrians
logit student i.sex $age $age_sex $par_char $geo if age>=10 & age<=19 & nationalitya==405 [pw=expan_indiv], vce(cluster currcluster)


est store student_4



**Add GRA 

*Model 5 -- 10-19 Syrians v. Jordanians among girls, GRA
logit student i.nationalitya $age $par_char $geo $ga if age>=10 & age<=19 & sex==2 [pw=expan_indiv], vce(cluster currcluster)


est store student_5

*Model 6 -- 10-19 Girls v. Boys among Syrians
logit student i.sex $age $age_sex $par_char $geo $ga if age>=10 & age<=19 & nationalitya==405 [pw=expan_indiv], vce(cluster currcluster)


est store student_6


**Add GB 

*Model 7 -- 10-19 Syrians v. Jordanians among girls, GRA
logit student i.nationalitya $age $par_char $geo $ga $gb if age>=10 & age<=19 & sex==2 [pw=expan_indiv], vce(cluster currcluster)


est store student_7


**Add test int. 

*Model 8a -- 10-19 Syrians v. Jordanians among girls, GRA
logit student i.nationalitya $age $par_char $geo $ga $gb $ga_nat $dv_nat $decision_nat $mobil_nat if age>=10 & age<=19 & sex==2 [pw=expan_indiv], vce(cluster currcluster)


*Test
test 405.nationalitya#c.factor_genderatt 405.nationalitya#c.mth_factor_genderatt 405.nationalitya#c.mth_diff_factor_genderatt  405.nationalitya#c.comm_factor_genderatt 
*insig

test 405.nationalitya#c.factor_dv  405.nationalitya#c.mth_factor_dv  405.nationalitya#c.comm_factor_dv
*sig

test 405.nationalitya#c.factor_decision  405.nationalitya#c.mth_factor_decision  405.nationalitya#c.comm_factor_decision 
*insig

test 405.nationalitya#c.factor_mobil  405.nationalitya#c.mth_factor_mobil  405.nationalitya#c.comm_factor_mobil 
*insig


*Model 8b -- 10-19 Syrians v. Jordanians among girls, GRA
logit student i.nationalitya $age $par_char $geo $ga $gb $dv_nat if age>=10 & age<=19 & sex==2 [pw=expan_indiv], vce(cluster currcluster)

est store student_8


*Graphing
coefplot (student_8), aseq mlabel() ///
 keep(405.nationalitya *genderatt* *decision* *mobil* *dv*) ///
 xscale(range(-3(1)3))  ///
 heading (factor_genderatt = "{bf: Gender role attitudes}" factor_dv = "{bf: Justification of domestic violence}" factor_decision="{bf: Decision-making}" factor_mobil="{bf: Mobility}" 405.nationalitya#c.factor_dv="{bf: Interactions w/ domestic violence justification}" ) ///
xline(0) xtick(-3(1)3) xlabel(-3(1)3) xtitle("Coefficient: enrollment") title("Girls") rename(405.nationalitya = "Syrian (Jordanian omit.)")

graph save "Graphs and Tables/coefplot_stu_girls.gph", replace
graph export "Graphs and Tables/coefplot_stu_girls.png", replace width(1500) 


*Model 9 -- 10-19 Girls v. Boys among Syrians
logit student i.sex $age $age_sex $par_char $geo $ga $ga_sex if age>=10 & age<=19 & nationalitya==405 [pw=expan_indiv], vce(cluster currcluster)


test 2.sex#c.factor_genderatt 2.sex#c.mth_factor_genderatt 2.sex#c.mth_diff_factor_genderatt  2.sex#c.comm_factor_genderatt 
*insig 

*est store student_9


*Graphing 
coefplot (student_6), aseq mlabel() ///
 keep(2.sex *genderatt*) ///
 xscale(range(-3(1)4))  ///
xline(0) xtick(-3(1)4) xlabel(-3(1)4) xtitle("Coefficient.: Enrollment") title("Syrians") rename(2.sex = "Female (male omit.)")


graph save "Graphs and Tables/coefplot_stu_syr.gph", replace
graph export "Graphs and Tables/coefplot_stu_syr.png", replace width(1500) 



*********
*Output
*********

/* Table for domestic hours */
esttab domestic_* ///
  using "Graphs and Tables/Tobits_domestic_hrs.csv", cells(b(star fmt(%9.3f)) se(par))   ///     
 stats(N r2_p converged, fmt(%9.0g %9.3g) labels("N obs." "Pseudo R-sq." "Converged")) label  ///
 nobase noomit refcat(11.age "Age (10 omit.):" 2.mteducst "Mother's ed (illit. omit.):" 2.fteducst "Father's ed: illit. omit." 2.dwealth "Household wealth deciles ( 1 (poorest) omit.):" 2.ftempst "Father's emp status (wage worker omit.):" 2.urb_rural_camps "Geography (urban omit.):" 11.age#2.sex "Age#sex (10 yo male omit.):", nolabel) ///
 mlabel ("Girls (aged 10 to 19)" "Syrians" "Girls" "Syrians") ///
  replace

 
  /* Table for Logit */
esttab student_* ///
  using "Graphs and Tables/logit.csv", cells(b(star fmt(%9.3f)) se(par))   ///     
 stats(N  r2_p converged, fmt(%9.0g %9.3g) labels("N obs."  "Pseudo R-sq." "Converged")) label  ///
 nobase noomit refcat(11.age "Age (10 omit.):" 2.mteducst "Mother's ed (illit. omit.):" 2.fteducst "Father's ed: illit. omit." 2.dwealth "Household wealth deciles (1 (poorest) omit.):" 2.ftempst "Father's emp status (wage worker omit.):" 2.urb_rural_camps "Geography (urban omit.):" 11.age#2.sex "Age#sex (10 yo male omit.):", nolabel) ///
  mlabel ("Educational Attainment: Girls (aged 10 to 19)" "Educational Attainment: Syrians" "Educational Attainment: Girls" "Educational Attainment: Syrians" ) replace eform


  
  
  
**************************************
*Single domestic work model for adults
***************************************

**********
*Merging in mother's and father's domestic hours
**********

*Mothers


use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear

*keep needed variables
keep hhid pn domestic_hrs

*Switch identifier to be able to merge. 
rename pn mthcode

*Rename domestic work variable
rename domestic_hrs mth_domestic_hrs

save "Data/mother domestic data.dta", replace


*Fathers

use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear

*keep needed variables
keep hhid pn domestic_hrs

*Switch identifier to be able to merge. 
rename pn fthcode

*Rename domestic work variable
rename domestic_hrs fth_domestic_hrs

save "Data/father domestic data.dta", replace

*Merge

use "Data/JLMPS 2016 xs v1.1 pt 1working data.dta", clear
*Merge on mother code and household id
merge m:1 mthcode hhid using "Data/mother domestic data.dta"
tabu _merge

*Drop people who were not mothers
drop if _merge==2
rename _merge mth_merge

*Merge on father code and household id
merge m:1 fthcode hhid using "Data/father domestic data.dta"
tabu _merge

*Drop people who were not mothers
drop if _merge==2
rename _merge fth_merge

*************
*Tobit model
*************

sort indid
set seed 304723


*Mother model 1: Syrian vs Jordanian girls
tobit mth_domestic_hrs i.nationalitya $age ///
$par_char $geo $ga $gb $dv_nat ///
if age>=10 & age<=19 & sex==2 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

estimates store mth_domestic_hrs_1

*Mother model 2: Syrian girls vs Syrian boys
tobit mth_domestic_hrs i.sex $age $age_sex ///
$par_char $geo $ga ///
if age>=10 & age<=19 & nationalitya==405 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

estimates store mth_domestic_hrs_2

*Father model 1: Syrian vs Jordanian girls
tobit fth_domestic_hrs i.nationalitya $age ///
$par_char $geo $ga $gb $dv_nat ///
if age>=10 & age<=19 & sex==2 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

estimates store fth_domestic_hrs_1

*Father model 2: Syrian girls vs Syrian boys
tobit fth_domestic_hrs i.sex $age $age_sex ///
$par_char $geo $ga ///
if age>=10 & age<=19 & nationalitya==405 [pw=expan_indiv], ll(0) vce(cluster currcluster) iter(50)

estimates store fth_domestic_hrs_2


la var fth_domestic_hrs "Father domestic hours"
la var mth_domestic_hrs "Mother domestic hours"

*Export tables
*mother
esttab mth_domestic* ///
  using "Graphs and Tables/parent_domestic.csv", cells(b(star fmt(%9.3f)) se(par))   ///     
 stats(N r2_p converged, fmt(%9.0g %9.3g) labels("N obs." "Pseudo R-sq." "Converged")) label  ///
 nobase noomit refcat(11.age "Age (10 omit.):" 2.mteducst "Mother's ed (illit. omit.):" 2.fteducst "Father's ed: illit. omit." 2.dwealth "Household wealth deciles ( 1 (poorest) omit.):" 2.ftempst "Father's emp status (wage worker omit.):" 2.urb_rural_camps "Geography (urban omit.):" 11.age#2.sex "Age#sex (10 yo male omit.):", nolabel) ///
 mlabel ("Girls (aged 10 to 19)" "Syrians" "Girls" "Syrians") ///
  replace
  
  *father
  esttab fth_domestic* ///
  using "Graphs and Tables/parent_domestic.csv", cells(b(star fmt(%9.3f)) se(par))   ///     
 stats(N r2_p converged, fmt(%9.0g %9.3g) labels("N obs." "Pseudo R-sq." "Converged")) label  ///
 nobase noomit refcat(11.age "Age (10 omit.):" 2.mteducst "Mother's ed (illit. omit.):" 2.fteducst "Father's ed: illit. omit." 2.dwealth "Household wealth deciles ( 1 (poorest) omit.):" 2.ftempst "Father's emp status (wage worker omit.):" 2.urb_rural_camps "Geography (urban omit.):" 11.age#2.sex "Age#sex (10 yo male omit.):", nolabel) ///
 mlabel ("Girls (aged 10 to 19)" "Syrians" "Girls" "Syrians") ///
  append
